pub enum SupportLevel {
Partial,
Incompatible(Severity),
Ignored,
Unrecognized,
}Expand description
The support level for a given configuration key.
Full support is omitted from the enum and those keys are not classified since there is nothing to be done about them downstream.
Variants
Partial
Partially supported.
Incompatible(Severity)
Explicitly incompatible.
Ignored
Intentionally ignored.
Unrecognized
Unrecognized.